@@ -1,6 +1,6 @@
 ;;; rec-mode.el --- Major mode for viewing/editing rec files
 
-;; Copyright (C) 2009-2014 Jose E. Marchesi
+;; Copyright (C) 2009-2015 Jose E. Marchesi
 
 ;; Maintainer: Jose E. Marchesi
 
@@ -34,6 +34,7 @@
 (eval-when-compile (require 'cl))
 (require 'calendar)
 (require 'hl-line)
+(require 'tabulated-list)
 
 ;;;; Customization
 
@@ -72,6 +73,10 @@ hidden by default in navigation mode.")
 (defvar rec-recfix "recfix"
   "Name of the 'recfix' utility from the GNU recutils.")
 
+(defface rec-field-name-face '((t :weight bold)) "" :group 'rec-mode)
+(defface rec-keyword-face '((t :weight bold)) "" :group 'rec-mode)
+(defface rec-continuation-line-face '((t :weight bold)) "" :group 'rec-mode)
+
 ;;;; Variables and constants that the user does not want to touch (really!)
 
 (defconst rec-mode-version "1.5"
@@ -139,9 +144,9 @@ hidden by default in navigation mode.")
   "Syntax table used in rec-mode")
 
 (defvar rec-font-lock-keywords
-`((,(concat "^" rec-keyword-prefix "[a-zA-Z0-9_]+:") . font-lock-keyword-face)
-  (,rec-field-name-re . font-lock-variable-name-face)
-  ("^\\+" . font-lock-constant-face))
+`((,(concat "^" rec-keyword-prefix "[a-zA-Z0-9_]+:") . rec-field-name-face)
+  (,rec-field-name-re . rec-keyword-face)
+  ("^\\+" . rec-continuation-line-face))
 "Font lock keywords used in rec-mode")
 
 (defvar rec-mode-edit-map
@@ -988,7 +993,7 @@ current buffer to look like indentation."
 (defun rec-remove-continuation-line-marker-overlays ()
   "Delete all the continuation line markers overlays."
   (mapc 'delete-overlay rec-continuation-line-markers-overlays)
-  (setq rec-continuation-line-markers-overlays))
+  (setq rec-continuation-line-markers-overlays nil))
 
 ;;;; Field folding
 
@@ -1483,23 +1488,25 @@ The result of the selection is stored in `rec-current-selection'."
   (interactive)
   (setq rec-current-selection (rec-query)))
 
-(defun rec-cmd-select-fast (str)
+(defun rec-cmd-select-fast (prefix str)
   "Perform a selection on the current record set using a fast string search.
 
 A prefix argument means to use a case-insensitive search."
-  (interactive "sFast string query: ")
+  (interactive "P\nsFast string query: ")
   (when (not (equal str ""))
     (setq rec-current-selection (rec-query :fast-string str
+                                           :icase prefix
                                            :type (rec-record-type)))
     (rec-navigate-selection)))
 
-(defun rec-cmd-select-sex (sex)
+(defun rec-cmd-select-sex (prefix sex)
   "Perform a selection on the current record set using a selection expression.
 
 A prefix argument means to use a case-insensitive search."
-  (interactive "sSelection expression: ")
+  (interactive "P\nsSelection expression: ")
   (when (not (equal sex ""))
     (setq rec-current-selection (rec-query :sex sex
+                                           :icase prefix
                                            :type (rec-record-type)))
     (rec-navigate-selection)))
 
@@ -1963,10 +1970,10 @@ This command is especially useful with enumerated types."
         (cmd (concat rec-recfix " "))
         (tmpfile (make-temp-file "rec-mode-")))
     (if buffer-file-name
-        (setq cmd (concat cmd buffer-file-name))
+        (setq cmd (concat cmd (shell-quote-argument buffer-file-name)))
       (with-temp-file tmpfile
         (insert-buffer-substring cur-buf))
-      (setq cmd (concat cmd tmpfile)))
+      (setq cmd (concat cmd (shell-quote-argument tmpfile))))
     (compilation-start cmd)))
 
 (defun rec-cmd-show-info ()
@@ -2151,7 +2158,7 @@ Turning on rec-mode calls the members of the variable
   (set-syntax-table rec-mode-syntax-table)
   (setq mode-name "Rec")
   (setq major-mode 'rec-mode)
-  (run-hooks 'rec-mode-hooks)
+  (run-hooks 'rec-mode-hook)
   ;; Goto the first record of the first type (including the Unknown).
   ;; If there is a problem (i.e.  syntax error) then go to fundamental
   ;; mode and show the output of recfix in a separated buffer.
