@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2012-05-25 15:16:18 jemarch"
+/* -*- mode: C -*-
  *
  *       File:         rec-aggregate.c
  *       Date:         Mon Apr 23 11:05:57 2012
@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2012 Jose E. Marchesi */
+/* Copyright (C) 2012-2015 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -364,13 +364,9 @@ rec_aggregate_std_avg_record (rec_record_t record,
      end-of-memory condition.  */                                       \
                                                                         \
   if (val == floor (val))                                               \
-    {                                                                   \
-      asprintf (&result, "%zu", (size_t) val);                          \
-    }                                                                   \
+      asprintf (&result, "%zd", (size_t) val);                          \
   else                                                                  \
-    {                                                                   \
       asprintf (&result, "%f", val);                                    \
-    }                                                                   \
                                                                         \
   return result;                                                        \
   }                                                                     \
