@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010-2013 Jose E. Marchesi */
+/* Copyright (C) 2010-2015 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -223,7 +223,8 @@ rec_sex_eval (rec_sex_t sex,
       nf = rec_record_get_num_fields_by_name (record, rec_field_name (field));
       if ((nf > 1)
           && (rec_record_field_mark (record, field) == 0)
-          && (rec_sex_ast_name_p (sex->ast, rec_field_name (field), nf)))
+          && (rec_sex_ast_name_p (sex->ast, rec_field_name (field), nf))
+          && (!rec_sex_ast_hash_name_p (sex->ast, rec_field_name (field))))
         {
           for (j = 0; j < nf; j++)
             {
