@@ -2,7 +2,7 @@
 #
 # recsel.sh - System tests for recsel.
 #
-# Copyright (C) 2010, 2011, 2012, 2013 Jose E. Marchesi.
+# Copyright (C) 2010-2015 Jose E. Marchesi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -128,6 +128,15 @@ field2: value22
 field3: value23
 '
 
+test_declare_input_file recurrent-fields-2 \
+'Name: foo
+Index: 5
+Index: 9
+
+Name: bar
+Index: 7
+'
+
 test_declare_input_file dates \
 'Date: Tue Nov 30 12:00:00 CET 2002
 
@@ -418,6 +427,14 @@ test_declare_input_file ignored-first-blanks \
 bar:	v2
 '
 
+test_declare_input_file negative_fields \
+'foo: 10
+bar: -10
+
+foo: 9
+bar: -9
+'
+
 #
 # Declare tests
 #
@@ -991,6 +1008,14 @@ field2: value121
 field2: value122
 '
 
+test_tool recsel-sex-sharp-multiple-2 ok \
+          recsel \
+          '-e "#Index = 1"' \
+          recurrent-fields-2 \
+'Name: bar
+Index: 7
+'
+
 test_tool recsel-sex-sharp-subname ok \
           recsel \
           '-t Package -j Maintainer -e "#Maintainer.URL" -P Maintainer.URL' \
@@ -1595,6 +1620,13 @@ Item: D
 TotalCost: 100
 '
 
+test_tool recsel-aggregate-sum-negative ok \
+          recsel \
+          '-p "Sum(bar):TotalBar"' \
+          negative_fields \
+'TotalBar: -19
+'
+
 test_tool recsel-aggregate-min-overall ok \
           recsel \
           '-P "Min(Cost)"' \
