@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010-2014 Jose E. Marchesi */
+/* Copyright (C) 2010-2015 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +47,8 @@
 #include <time.h>
 #include <unistd.h>
 #include <getpass.h>
+#include <tmpdir.h>
+#include <pathmax.h>
 
 #include <rec.h>
 #include <recutl.h>
@@ -174,7 +176,7 @@ recutl_print_version (void)
 Copyright (C) %s Jose E. Marchesi.\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n\
 This is free software: you are free to change and redistribute it.\n\
-There is NO WARRANTY, to the extent permitted by law.\n"), "2010, 2011, 2012, 2013, 2014");
+There is NO WARRANTY, to the extent permitted by law.\n"), "2010-2018");
 
   puts (_("\
 \n\
@@ -389,7 +391,7 @@ recutl_write_db_to_file (rec_db_t db,
                          char *file_name)
 {
   FILE *out;
-  char tmp_file_name[10]="recXXXXXX";
+  char tmp_file_name[PATH_MAX];
   rec_writer_t writer;
   int des;
   struct stat st1;
@@ -405,11 +407,11 @@ recutl_write_db_to_file (rec_db_t db,
       stat_result = stat (file_name, &st1);
 
       /* Create a temporary file with the results. */
-      des = mkstemp (tmp_file_name);
-      if (des == -1)
-        {
-          recutl_fatal (_("cannot create a unique name.\n"));
-        }
+      if ((path_search (tmp_file_name, PATH_MAX, NULL,
+                        "rec", true) == -1)
+          || ((des = mkstemp (tmp_file_name)) == -1))
+        recutl_fatal (_("cannot create a unique name.\n"));
+
       out = fdopen (des, "w+");
     }
 
